@@ -80,7 +80,10 @@ def spark_session(request: Any) -> SparkSession:
         .config("spark.sql.shuffle.partitions", "2")
         .config("spark.default.parallelism", "4")
         .config("spark.sql.broadcastTimeout", "2400")
-        .config("spark.jars.packages", "com.crealytics:spark-excel_2.12:0.13.7")
+        .config(
+            "spark.jars.packages",
+            "com.crealytics:spark-excel_2.12:0.13.7,com.databricks:spark-xml_2.12:0.14.0",
+        )
         .enableHiveSupport()
         .getOrCreate()
     )
